#
# spec file for package python-gst
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _name gst-python
Name:           python-gst
Version:        1.12.5
Release:        lp150.1.1
Summary:        Python Bindings for GStreamer
License:        LGPL-2.1-or-later
Group:          Development/Languages/Python
URL:            http://www.gstreamer.net/
Source:         https://gstreamer.freedesktop.org/src/gst-python/%{_name}-%{version}.tar.xz
BuildRequires:  %{python_module devel}
BuildRequires:  gobject-introspection
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(gstreamer-1.0) >= 1.12.0
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0) >= 1.12.0
BuildRequires:  pkgconfig(pygobject-3.0) >= 3.0
Requires:       gstreamer >= 1.11.1

%description
This module contains a wrapper that allows GStreamer applications to be
written in Python.

%python_subpackages

%package -n gstreamer-plugin-python
Summary:        GStreamer 1.0 plugin for python
Group:          System/Libraries

%description -n gstreamer-plugin-python
This module contains a wrapper that allows GStreamer applications to be
written in Python.

%prep
%setup -q -n %{_name}-%{version}

%build
for py_var in %{pythons}; do
  mkdir ../$py_var
  cp -rp * ../$py_var
  pushd ../$py_var
  # link ../configure, so we can still use the macro
  export PYTHON=$py_var
  %configure \
    --disable-static
  make %{?_smp_mflags}
  popd
done

%install
for py_var in %{pythons}; do
  pushd ../$py_var
  %make_install
  popd
done
find %{buildroot} -type f -name "*.la" -delete -print
rm %{buildroot}%{_libdir}/gstreamer-1.0/libgstpythonplugin.so

%files %{python_files}
%license COPYING
%doc NEWS TODO
%{python_sitearch}/gi/overrides/

%files -n gstreamer-plugin-python
%{_libdir}/gstreamer-1.0/libgstpythonplugin.cpython*.so

%changelog
* Fri Mar 30 2018 bjorn.lie@gmail.com
- Update to version 1.12.5:
  + Bugs fixed: bgo#793560, bgo#793756.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Dec 11 2017 zaitor@opensuse.org
- Update to version 1.12.4:
  + No changes, stable version bump only.
* Mon Sep 18 2017 zaitor@opensuse.org
- Update to version 1.12.3:
  + plugin: Always initialize GIL state.
  + Add support for Gst.Bitmask.
  + tests: Stop using deprecated assertion methods.
  + tests: Move all Fundamental types tests in a file.
  + structure: Add a .keys() method and implement __str__.
  + Return a Gst.*Range instead of a python range converting from
    GValue to python.
  + structures: Override __new__ to make it more pythonic.
  + overrides: Remove IntRange And Int64Range on Python2.
* Fri Jul 14 2017 dimstar@opensuse.org
- Convert to single-spec.
* Fri Jul 14 2017 zaitor@opensuse.org
- Update to version 1.12.2:
  + No changes, stable version bump only.
* Wed Jun 21 2017 zaitor@opensuse.org
- Update to version 1.12.1:
  + No changes, stable version bump only.
* Wed May 10 2017 zaitor@opensuse.org
- Update to version 1.12.0:
  + No changes, stable version bump only.
- Changes from version 1.11.91:
  + No changes.
- Changes from version 1.11.90:
  + Bugs fixed: bgo#780369.
* Sat Feb 25 2017 zaitor@opensuse.org
- Update to version 1.11.2:
  + Port old helloworld.py example to GI.
  + python: Add an option to set where to install pygi overrides.
  + meson: bump version and bump meson requirement.
* Thu Feb 23 2017 zaitor@opensuse.org
- Update to version 1.11.1:
  + Meson build fixes and updates.
  + Play nicely with gst-build uninstalled.
  + common: use https protocol for common submodule.
  + Remove bitrotten and unused gst-python.spec.in file.
* Thu Feb 23 2017 zaitor@opensuse.org
- Update to version 1.10.4:
  + No changes, versionbump only.
* Mon Jan 30 2017 zaitor@opensuse.org
- Update to version 1.10.3:
  + No changes, versionbump only.
* Mon Jan  9 2017 dimstar@opensuse.org
- Add gobject-introspection BuildRequires: needed in order to get
  automatic typelib() Requires added to the package (boo#1017473).
* Sat Dec  3 2016 zaitor@opensuse.org
- Update to version 1.10.2:
  + No changes, version bump only.
* Sun Nov 27 2016 zaitor@opensuse.org
- Update to version 1.10.1:
  + No changes, versionbump only.
- Changes from version 1.10.0:
  + Bugs fixed: bgo#772853.
* Wed Aug 24 2016 zaitor@opensuse.org
- Update to version 1.8.3 (boo#996937):
  + No changes, versionbump only.
* Wed Jun 15 2016 zaitor@opensuse.org
- Update to version 1.8.2:
  + No changes, version bump only.
* Thu Apr 21 2016 zaitor@opensuse.org
- Update to version 1.8.1:
  + No changes, version bump only.
* Wed Mar 16 2016 zaitor@opensuse.org
- Update to version 1.8.0:
  + Hardware-accelerated zero-copy video decoding on Android
  + New video capture source for Android using the
    android.hardware.Camera API.
  + Windows Media reverse playback support (ASF/WMV/WMA).
  + New tracing system provides support for more sophisticated
    debugging tools.
  + New high-level GstPlayer playback convenience API.
  + Initial support for the new Vulkan API, see Matthew Waters'
    blog post for more details.
  + Improved Opus audio codec support: Support for more than two
    channels; MPEG-TS demuxer/muxer can now handle Opus;
    sample-accurate encoding/decoding/transmuxing with Ogg,
    Matroska, ISOBMFF (Quicktime/MP4), and MPEG-TS as container;
    new codec utility functions for Opus header and caps handling
    in pbutils library. The Opus encoder/decoder elements were
    also moved to gst-plugins-base (from -bad), and the opus RTP
    depayloader/payloader to -good.
  + GStreamer VAAPI module now released and maintained as part of
    the GStreamer project.
  + Asset proxy support in the GStreamer Editing Services.
- Replace gstreamer-plugins-base-devel for
  pkgconfig(gstreamer-plugins-base-1.0) BuildRequires and version
  it.
- Add explicit pkgconfig(gstreamer-1.0) BuildRequires.
* Sat Feb  6 2016 zaitor@opensuse.org
- Update to version 1.6.2:
  + overrides: fix a few typos in exception messages.
  + python:
  - Check return value of g_module_symbol().
  - Don't call Py_DECREF() on NULL.
  + pythonplugin: Clean up error handling a bit.
* Mon Nov 23 2015 zaitor@opensuse.org
- Update to version 1.6.1:
  + Fix regression creating (Ghost)Pad (bgo#757108).
- Changes from version 1.6.0:
  + tests:
  - Fix tests in python2.
  - Add test_fraction back in the testsuite.
  - Bring back the testsuite and test if the initialization
    override works.
  + overrides:
  - Do not use inspect.signature as it is not avalaible in
    python2.
  - Disable all GStreamer APIs until Gst has been initialized.
  - Try hard to make the query writable in the pad query
    function.
  + Remove INSTALL file.
  + plugin: Name differently between python2 and python3.
* Mon Oct 20 2014 dimstar@opensuse.org
- Update to version 1.4.0:
  + pythonplugin: Fix compiler warning about unused format string
    argument.
* Sat Oct 11 2014 dimstar@opensuse.org
- Update to version 1.3.90:
  + Sync up for releasse with GStreamer 1.4.x.
- Split new subpackage gstreamer-plugin-python, when building for
  python3.
* Thu Sep 11 2014 dimstar@opensuse.org
- Initial package, python gstreamer; bindings for GStreamer 1.0,
  version 1.2.1.
